@@ -1,8 +1,23 @@
+#  Copyright 2000-2004  The Apache Software Foundation
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+
 use strict;
 use Apache::Request ();
 
 my $r = shift;
 my $apr = Apache::Request->new($r);
+$apr->no_cache(1);
 $apr->send_http_header('text/html');
 
 my $title = "File Upload Example";
@@ -35,6 +50,11 @@ if (my $upload = $apr->upload) {
     my $fh = $upload->fh;
     my $size = $upload->size;
 
+    unless ($filename) {
+	print "no file specified";
+	return;
+    }
+
     print <<EOF;
 <hr>
 <h2>$name</h2>
@@ -62,3 +82,4 @@ EOF
 	print "No statistics selected.\n";
     }
 }
+print "</BODY></HTML>";
